@@ -1,6 +1,6 @@
 import random,os
 from multiprocessing.pool import Pool
-from top_keyword import *
+from qm_spider.top_keyword import *
 from threading_py import *
 
 
